==> istio-model-v1alpha3-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Double;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HTTPFaultInjectionAbortFluent<A extends HTTPFaultInjectionAbortFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildErrorType instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsHTTPFaultInjectionAbortErrorType getErrorType();
  public IsHTTPFaultInjectionAbortErrorType buildErrorType();
  public A withErrorType(IsHTTPFaultInjectionAbortErrorType errorType);
  public Boolean hasErrorType();
  public A withHTTPFaultInjectionAbortHttpStatusErrorType(HTTPFaultInjectionAbortHttpStatus hTTPFaultInjectionAbortHttpStatusErrorType);
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttpStatusErrorType();
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttpStatusErrorTypeLike(HTTPFaultInjectionAbortHttpStatus item);
  public A withNewHTTPFaultInjectionAbortHttpStatusErrorType(Integer httpStatus);
  public A withHTTPFaultInjectionAbortHttp2ErrorType(HTTPFaultInjectionAbortHttp2Error hTTPFaultInjectionAbortHttp2ErrorType);
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttp2ErrorType();
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttp2ErrorTypeLike(HTTPFaultInjectionAbortHttp2Error item);
  public A withNewHTTPFaultInjectionAbortHttp2ErrorType(String http2Error);
  public A withHTTPFaultInjectionAbortGrpcStatusErrorType(HTTPFaultInjectionAbortGrpcStatus hTTPFaultInjectionAbortGrpcStatusErrorType);
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortGrpcStatusErrorType();
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortGrpcStatusErrorTypeLike(HTTPFaultInjectionAbortGrpcStatus item);
  public A withNewHTTPFaultInjectionAbortGrpcStatusErrorType(String grpcStatus);
  
  /**
   * This method has been deprecated, please use method buildPercentage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Percent getPercentage();
  public Percent buildPercentage();
  public A withPercentage(Percent percentage);
  public Boolean hasPercentage();
  public A withNewPercentage(Double value);
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> withNewPercentage();
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> withNewPercentageLike(Percent item);
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editPercentage();
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editOrNewPercentage();
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editOrNewPercentageLike(Percent item);
  public interface HTTPFaultInjectionAbortHttpStatusErrorTypeNested<N> extends Nested<N>,HTTPFaultInjectionAbortHttpStatusFluent<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionAbortHttpStatusErrorType();
    
  }
  public interface HTTPFaultInjectionAbortHttp2ErrorTypeNested<N> extends Nested<N>,HTTPFaultInjectionAbortHttp2ErrorFluent<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionAbortHttp2ErrorType();
    
  }
  public interface HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<N> extends Nested<N>,HTTPFaultInjectionAbortGrpcStatusFluent<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionAbortGrpcStatusErrorType();
    
  }
  public interface PercentageNested<N> extends Nested<N>,PercentFluent<HTTPFaultInjectionAbortFluent.PercentageNested<N>>{
    public N and();
    public N endPercentage();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/HTTPFaultInjectionAbortFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Double;
import java.lang.Integer;

 /**
  * Generated
  */
public interface HTTPFaultInjectionAbortFluent<A extends HTTPFaultInjectionAbortFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildErrorType instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsHTTPFaultInjectionAbortErrorType getErrorType();
  public IsHTTPFaultInjectionAbortErrorType buildErrorType();
  public A withErrorType(IsHTTPFaultInjectionAbortErrorType errorType);
  public Boolean hasErrorType();
  public A withHTTPFaultInjectionAbortHttpStatusErrorType(HTTPFaultInjectionAbortHttpStatus hTTPFaultInjectionAbortHttpStatusErrorType);
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttpStatusErrorType();
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttpStatusErrorTypeLike(HTTPFaultInjectionAbortHttpStatus item);
  public A withNewHTTPFaultInjectionAbortHttpStatusErrorType(Integer httpStatus);
  public A withHTTPFaultInjectionAbortHttp2ErrorType(HTTPFaultInjectionAbortHttp2Error hTTPFaultInjectionAbortHttp2ErrorType);
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttp2ErrorType();
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<A> withNewHTTPFaultInjectionAbortHttp2ErrorTypeLike(HTTPFaultInjectionAbortHttp2Error item);
  public A withNewHTTPFaultInjectionAbortHttp2ErrorType(String http2Error);
  public A withHTTPFaultInjectionAbortGrpcStatusErrorType(HTTPFaultInjectionAbortGrpcStatus hTTPFaultInjectionAbortGrpcStatusErrorType);
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortGrpcStatusErrorType();
  public HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<A> withNewHTTPFaultInjectionAbortGrpcStatusErrorTypeLike(HTTPFaultInjectionAbortGrpcStatus item);
  public A withNewHTTPFaultInjectionAbortGrpcStatusErrorType(String grpcStatus);
  
  /**
   * This method has been deprecated, please use method buildPercentage instead.
   * @return The buildable object.
   */
  @Deprecated
  public Percent getPercentage();
  public Percent buildPercentage();
  public A withPercentage(Percent percentage);
  public Boolean hasPercentage();
  public A withNewPercentage(Double value);
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> withNewPercentage();
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> withNewPercentageLike(Percent item);
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editPercentage();
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editOrNewPercentage();
  public HTTPFaultInjectionAbortFluent.PercentageNested<A> editOrNewPercentageLike(Percent item);
  public interface HTTPFaultInjectionAbortHttpStatusErrorTypeNested<N> extends Nested<N>,HTTPFaultInjectionAbortHttpStatusFluent<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttpStatusErrorTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionAbortHttpStatusErrorType();
    
  }
  public interface HTTPFaultInjectionAbortHttp2ErrorTypeNested<N> extends Nested<N>,HTTPFaultInjectionAbortHttp2ErrorFluent<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortHttp2ErrorTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionAbortHttp2ErrorType();
    
  }
  public interface HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<N> extends Nested<N>,HTTPFaultInjectionAbortGrpcStatusFluent<HTTPFaultInjectionAbortFluent.HTTPFaultInjectionAbortGrpcStatusErrorTypeNested<N>>{
    public N and();
    public N endHTTPFaultInjectionAbortGrpcStatusErrorType();
    
  }
  public interface PercentageNested<N> extends Nested<N>,PercentFluent<HTTPFaultInjectionAbortFluent.PercentageNested<N>>{
    public N and();
    public N endPercentage();
    
  }
  
}
